@@ -1,3 +1,4 @@
+# -*- cperl-indent-level: 2  -*-
 package CPAN::Checksums;
 
 use strict;
@@ -18,7 +19,7 @@ require Exporter;
 
 @ISA = qw(Exporter);
 @EXPORT_OK = qw(updatedir);
-$VERSION = "2.09";
+$VERSION = "2.12";
 $VERSION =~ s/_//;
 $CAUTION ||= 0;
 $TRY_SHORTNAME ||= 0;
@@ -121,6 +122,14 @@ sub _dir_to_dref {
           last COMPARE;
         }
       }
+      if ($can_reuse_old_md5
+          and $de =~ /\.(gz|tgz|bz2|tbz)$/
+          and exists $old_dref->{$de}{md5}
+          and !exists $old_dref->{$de}{"md5-ungz"}
+          and !exists $old_dref->{$de}{"md5-unbz2"}
+         ) {
+        $can_reuse_old_md5 = 0;
+      }
       if ( $can_reuse_old_md5 ) {
         for my $param (qw(md5 md5-ungz md5-unbz2)) {
           next unless exists $old_dref->{$de}{$param};
@@ -227,7 +236,7 @@ sub _add_digests ($$$$$$$) {
   my $digest = $dig->hexdigest;
   $dref->{$de}{$keyname} = $digest;
   $dig = $module->new(@$constructor_args);
-  if ($de =~ /\.gz$/) {
+  if ($de =~ /\.(gz|tgz)$/) {
     my($buffer, $zip);
     if (exists $old_dref->{$de}{$keyname} &&
         $dref->{$de}{$keyname} eq $old_dref->{$de}{$keyname} &&
@@ -242,7 +251,7 @@ sub _add_digests ($$$$$$$) {
       $dref->{$de}{"$keyname-ungz"} = $dig->hexdigest;
       $zip->gzclose;
     }
-  } elsif ($de =~ /\.bz2$/) {
+  } elsif ($de =~ /\.(bz2|tbz)$/) {
     my($buffer, $zip);
     if (exists $old_dref->{$de}{$keyname} &&
         $dref->{$de}{$keyname} eq $old_dref->{$de}{$keyname} &&
